@@ -7,7 +7,7 @@ import types
 from errno import ECONNREFUSED
 from typing import Any
 from unittest import mock
-from unittest.mock import call, patch
+from unittest.mock import call, patch, MagicMock, Mock
 
 import pytest
 import redis
@@ -20,6 +20,7 @@ from redis.cache import (
     CacheEntryStatus,
     CacheInterface,
     CacheKey,
+    CacheProxy,
     DefaultCache,
     LRUPolicy,
 )
@@ -29,9 +30,18 @@ from redis.connection import (
     SSLConnection,
     UnixDomainSocketConnection,
     parse_url,
+    BlockingConnectionPool,
 )
 from redis.credentials import UsernamePasswordCredentialProvider
+from redis.event import (
+    EventDispatcher,
+)
 from redis.exceptions import ConnectionError, InvalidResponse, RedisError, TimeoutError
+from redis.observability.attributes import (
+    DB_CLIENT_CONNECTION_POOL_NAME,
+    DB_CLIENT_CONNECTION_STATE,
+    ConnectionState,
+)
 from redis.retry import Retry
 from redis.utils import HIREDIS_AVAILABLE
 
@@ -124,16 +134,31 @@ class TestConnection:
         assert conn._connect.call_count == 3
         self.clear(conn)
 
-    def test_connect_without_retry_on_os_error(self):
-        """Test that the _connect function is not being retried in case of a OSError"""
+    def test_connect_without_retry_on_non_retryable_error(self):
+        """Test that the _connect function is not being retried in case of a non-retryable error"""
         with patch.object(Connection, "_connect") as _connect:
-            _connect.side_effect = OSError("")
+            _connect.side_effect = RedisError("")
             conn = Connection(retry_on_timeout=True, retry=Retry(NoBackoff(), 2))
-            with pytest.raises(ConnectionError):
+            with pytest.raises(RedisError):
                 conn.connect()
             assert _connect.call_count == 1
             self.clear(conn)
 
+    def test_connect_with_retries(self):
+        """
+        Validate that retries occur for the entire connect+handshake flow when OSError
+        happens during the handshake phase.
+        """
+        with patch.object(socket.socket, "sendall") as sendall:
+            sendall.side_effect = OSError(ECONNREFUSED)
+            conn = Connection(retry_on_timeout=True, retry=Retry(NoBackoff(), 2))
+            with pytest.raises(ConnectionError):
+                conn.connect()
+            # the handshake commands are the failing ones
+            # validate that we don't execute too many commands on each retry
+            # 3 retries --> 3 commands
+            assert sendall.call_count == 3
+
     def test_connect_timeout_error_without_retry(self):
         """Test that the _connect function is not being retried if retry_on_timeout is
         set to False"""
@@ -405,7 +430,9 @@ class TestUnitConnectionPool:
             cache_factory=mock_cache_factory,
         )
 
-        assert connection_pool.cache == mock_cache
+        # Cache is wrapped in CacheProxy for observability
+        assert isinstance(connection_pool.cache, CacheProxy)
+        assert connection_pool.cache._cache == mock_cache
         connection_pool.disconnect()
 
     def test_creates_cache_with_given_configuration(self, mock_cache):
@@ -446,7 +473,9 @@ class TestUnitCacheProxyConnection:
         mock_connection.retry = "mock"
         mock_connection.host = "mock"
         mock_connection.port = "mock"
+        mock_connection.db = 0
         mock_connection.credential_provider = UsernamePasswordCredentialProvider()
+        mock_connection._event_dispatcher = EventDispatcher()
 
         proxy_connection = CacheProxyConnection(
             mock_connection, cache, threading.RLock()
@@ -463,7 +492,9 @@ class TestUnitCacheProxyConnection:
         mock_connection.retry = "mock"
         mock_connection.host = "mock"
         mock_connection.port = "mock"
+        mock_connection.db = 0
         mock_connection.credential_provider = UsernamePasswordCredentialProvider()
+        mock_connection._event_dispatcher = EventDispatcher()
 
         mock_cache.is_cachable.return_value = True
         mock_cache.get.side_effect = [
@@ -573,7 +604,9 @@ class TestUnitCacheProxyConnection:
         mock_connection.retry = "mock"
         mock_connection.host = "mock"
         mock_connection.port = "mock"
+        mock_connection.db = 0
         mock_connection.credential_provider = UsernamePasswordCredentialProvider()
+        mock_connection._event_dispatcher = Mock(spec=EventDispatcher)
 
         another_conn = copy.deepcopy(mock_connection)
         another_conn.can_read.side_effect = [True, False]
@@ -598,3 +631,213 @@ class TestUnitCacheProxyConnection:
         assert proxy_connection.read_response() == b"bar"
         assert another_conn.can_read.call_count == 2
         another_conn.read_response.assert_called_once()
+
+
+class TestConnectionPoolGetConnectionCount:
+    """Tests for ConnectionPool.get_connection_count() method."""
+
+    def test_get_connection_count_returns_idle_and_used_counts(self):
+        """Test that get_connection_count returns both idle and used connection counts."""
+        pool = ConnectionPool(max_connections=10)
+
+        # Initially, no connections exist
+        counts = pool.get_connection_count()
+        assert len(counts) == 2
+
+        # Check idle connections count
+        idle_count, idle_attrs = counts[0]
+        assert idle_count == 0
+        assert DB_CLIENT_CONNECTION_POOL_NAME in idle_attrs
+        assert idle_attrs[DB_CLIENT_CONNECTION_STATE] == ConnectionState.IDLE.value
+
+        # Check used connections count
+        used_count, used_attrs = counts[1]
+        assert used_count == 0
+        assert DB_CLIENT_CONNECTION_POOL_NAME in used_attrs
+        assert used_attrs[DB_CLIENT_CONNECTION_STATE] == ConnectionState.USED.value
+
+        pool.disconnect()
+
+    def test_get_connection_count_with_connections_in_use(self):
+        """Test get_connection_count when connections are in use."""
+
+        pool = ConnectionPool(max_connections=10)
+
+        # Create mock connections
+        mock_conn1 = MagicMock()
+        mock_conn1.pid = pool.pid
+
+        mock_conn2 = MagicMock()
+        mock_conn2.pid = pool.pid
+
+        # Simulate connections in use
+        pool._in_use_connections.add(mock_conn1)
+        pool._in_use_connections.add(mock_conn2)
+
+        counts = pool.get_connection_count()
+
+        idle_count, idle_attrs = counts[0]
+        used_count, used_attrs = counts[1]
+
+        assert idle_count == 0
+        assert used_count == 2
+        assert idle_attrs[DB_CLIENT_CONNECTION_STATE] == ConnectionState.IDLE.value
+        assert used_attrs[DB_CLIENT_CONNECTION_STATE] == ConnectionState.USED.value
+
+        pool.disconnect()
+
+    def test_get_connection_count_with_available_connections(self):
+        """Test get_connection_count when connections are available (idle)."""
+
+        pool = ConnectionPool(max_connections=10)
+
+        # Create mock connections
+        mock_conn1 = MagicMock()
+        mock_conn1.pid = pool.pid
+
+        mock_conn2 = MagicMock()
+        mock_conn2.pid = pool.pid
+
+        mock_conn3 = MagicMock()
+        mock_conn3.pid = pool.pid
+
+        # Simulate available connections
+        pool._available_connections.append(mock_conn1)
+        pool._available_connections.append(mock_conn2)
+        pool._available_connections.append(mock_conn3)
+
+        counts = pool.get_connection_count()
+
+        idle_count, idle_attrs = counts[0]
+        used_count, used_attrs = counts[1]
+
+        assert idle_count == 3
+        assert used_count == 0
+        assert idle_attrs[DB_CLIENT_CONNECTION_STATE] == ConnectionState.IDLE.value
+        assert used_attrs[DB_CLIENT_CONNECTION_STATE] == ConnectionState.USED.value
+
+        pool.disconnect()
+
+    def test_get_connection_count_mixed_connections(self):
+        """Test get_connection_count with both idle and used connections."""
+
+        pool = ConnectionPool(max_connections=10)
+
+        # Create mock connections
+        mock_idle = MagicMock()
+        mock_idle.pid = pool.pid
+
+        mock_used1 = MagicMock()
+        mock_used1.pid = pool.pid
+
+        mock_used2 = MagicMock()
+        mock_used2.pid = pool.pid
+
+        # Simulate mixed state
+        pool._available_connections.append(mock_idle)
+        pool._in_use_connections.add(mock_used1)
+        pool._in_use_connections.add(mock_used2)
+
+        counts = pool.get_connection_count()
+
+        idle_count, _ = counts[0]
+        used_count, _ = counts[1]
+
+        assert idle_count == 1
+        assert used_count == 2
+
+        pool.disconnect()
+
+    def test_get_connection_count_includes_pool_name_in_attributes(self):
+        """Test that get_connection_count includes pool name in attributes."""
+        from redis.observability.attributes import get_pool_name
+
+        pool = ConnectionPool(max_connections=10)
+
+        counts = pool.get_connection_count()
+
+        _, idle_attrs = counts[0]
+        _, used_attrs = counts[1]
+
+        # Both should have the pool name
+        assert DB_CLIENT_CONNECTION_POOL_NAME in idle_attrs
+        assert DB_CLIENT_CONNECTION_POOL_NAME in used_attrs
+
+        # Pool name should match the format from get_pool_name() (host:port_uniqueID)
+        expected_pool_name = get_pool_name(pool)
+        assert idle_attrs[DB_CLIENT_CONNECTION_POOL_NAME] == expected_pool_name
+        assert used_attrs[DB_CLIENT_CONNECTION_POOL_NAME] == expected_pool_name
+
+        # Verify the pool name has the expected format (host:port_uniqueID)
+        assert "unknown:6379_" in expected_pool_name
+
+        # Verify the unique ID is 8 hex characters (matching go-redis)
+        parts = expected_pool_name.split("_")
+        assert len(parts) == 2, (
+            f"Pool name should have format host:port_id, got: {expected_pool_name}"
+        )
+        unique_id = parts[1]
+        assert len(unique_id) == 8, (
+            f"Unique ID should be 8 characters, got: {unique_id}"
+        )
+
+        pool.disconnect()
+
+
+class TestBlockingConnectionPoolGetConnectionCount:
+    """Tests for BlockingConnectionPool.get_connection_count() method."""
+
+    def test_get_connection_count_returns_idle_and_used_counts(self):
+        """Test that BlockingConnectionPool.get_connection_count returns both counts."""
+
+        pool = BlockingConnectionPool(max_connections=10)
+
+        # Initially, no connections exist
+        counts = pool.get_connection_count()
+        assert len(counts) == 2
+
+        idle_count, idle_attrs = counts[0]
+        used_count, used_attrs = counts[1]
+
+        assert idle_count == 0
+        assert used_count == 0
+        assert idle_attrs[DB_CLIENT_CONNECTION_STATE] == ConnectionState.IDLE.value
+        assert used_attrs[DB_CLIENT_CONNECTION_STATE] == ConnectionState.USED.value
+
+        pool.disconnect()
+
+    def test_get_connection_count_with_connections_in_queue(self):
+        """Test get_connection_count when connections are in the queue (idle)."""
+
+        pool = BlockingConnectionPool(max_connections=10)
+
+        # Create mock connections and add to queue
+        mock_conn1 = MagicMock()
+        mock_conn1.pid = pool.pid
+
+        mock_conn2 = MagicMock()
+        mock_conn2.pid = pool.pid
+
+        # Add connections to the pool's internal list and queue
+        pool._connections.append(mock_conn1)
+        pool._connections.append(mock_conn2)
+
+        # Clear the queue and add our connections
+        while not pool.pool.empty():
+            try:
+                pool.pool.get_nowait()
+            except Exception:
+                break
+
+        pool.pool.put_nowait(mock_conn1)
+        pool.pool.put_nowait(mock_conn2)
+
+        counts = pool.get_connection_count()
+
+        idle_count, _ = counts[0]
+        used_count, _ = counts[1]
+
+        assert idle_count == 2
+        assert used_count == 0
+
+        pool.disconnect()
